# cody.py (Explorer Workshop)
# Copyright: 2024 Bradan Lane STUDIO
#
# Open Source License: MIT

'''
This CircuitPython program is a sample from the 'Hack the Badge' workshop

Implementation Notes
--------------------
**Hardware:**
    * one of the Explorer Badge designs

**Software and Dependencies:**
    * CircuitPython firmware (UF2): https://circuitpython.org
    * Adafruit CircuitPython Libraries: https://circuitpython.org/libraries

**Open Source Repository:**
    * GitLab: https://gitlab.com/bradanlane/exp_tutorial
    
'''

import time
import board
import neopixel


''' setup the Neopixel LEDs '''
NEOPIXEL_COUNT: int = 9
leds = neopixel.NeoPixel(board.NEOPIXEL, NEOPIXEL_COUNT, brightness=0.15, auto_write=True)

# lets quickly cycle all the neopixels through a range of colors
colors: list = [0x0000FF, 0x00FF00, 0x00FFFF, 0xFF0000, 0xFF00FF, 0xFFFF00, 0xFFFFFF, 0x000000]
COLOR_COUNT: int = 8
color_index: int = 0


counter: int = 0
try:
    while True:
        if not (counter % NEOPIXEL_COUNT):                      # each time the counter is a multiple of NEOPIXEL_COUNT
            color_index = (color_index + 1) % COLOR_COUNT       # we change the color
        leds[counter % NEOPIXEL_COUNT] = colors[color_index]    # change the color of a single neopixel
        
        counter += 1
        print(counter)
        time.sleep(0.05)

finally:
    leds.fill(0x000000)    # set all the Neopixels to black
